@@ -6,7 +6,7 @@ from tests.pipeline.base import PipelineTest
 
 class TestDataTransformationPipeline(PipelineTest):
 
-    def test_create_and_run_generator_pipeline_from_func(self):
+    def test_create_and_run_transformation_pipeline_from_func(self):
         dtp = self.create_transformation_pipeline()
         dtp.execute()
 
@@ -25,6 +25,27 @@ class TestDataTransformationPipeline(PipelineTest):
         df = ds.df
         assert_frame_equal(df, self.expect_func_df)
 
+    def test_auto_run_pipeline_by_load_source_with_no_location_and_shared_columns(self):
+        self.create_csv()
+        all_cols = self.create_columns()
+
+        def transform_func(source: DataSource) -> DataSource:
+            new_ds = DataSource(df=source.df, columns=all_cols)
+            return new_ds
+
+        dtp = self.create_transformation_pipeline(func=transform_func)
+
+        ds = DataSource(pipeline=dtp, location=self.csv_path_output, columns=all_cols)
+        df = ds.df
+        assert_frame_equal(df, self.expect_loaded_df_rename_only)
+
+    def test_create_nested_transformation_pipeline(self):
+        dtp = self.create_transformation_pipeline()
+
+        dtp2 = self.create_transformation_pipeline(source=dtp)
+        dtp2.execute()
+        assert_frame_equal(dtp2.df, self.expect_df_double_source_transform)
+
     def test_create_nested_generation_pipeline(self):
         dgp = self.create_generator_pipeline()
 
